@@ -80,7 +80,8 @@ class Decanter(Daemon):
         """
         Command to run for development environments.
         """
-        print(textwrap.dedent("""{2}
+        print(textwrap.dedent("""
+            {2}
             Welcome to Decanter!
             You're ready to go!
             Server running on port {0}
